/*
 * Copyright (c) 2006 Extreme! Lab, Indiana University. All rights reserved.
 *
 * This software is open source. See the bottom of this file for the license.
 *
 * $Id: ComponentTreeNode.java,v 1.3 2006/11/20 18:35:12 sshirasu Exp $
 */
package edu.indiana.extreme.xbaya.component.gui;

import java.util.List;

import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.MutableTreeNode;

import edu.indiana.extreme.xbaya.component.registry.ComponentReference;
import edu.indiana.extreme.xbaya.component.registry.ComponentRegistry;

/**
 * @author Satoshi Shirasuna
 */
public class ComponentTreeNode extends DefaultMutableTreeNode {

    private ComponentReference componentReference;

    private ComponentRegistry componentRegistry;

    /**
     * Constructs a ComponentTreeNode.
     * 
     * @param name
     */
    public ComponentTreeNode(String name) {
        super(name);
    }

    /**
     * Constructs a ComponentTreeNode.
     * 
     * @param componentReference
     */
    public ComponentTreeNode(ComponentReference componentReference) {
        super(componentReference);
        this.componentReference = componentReference;
    }
    
    /**
     * Constructs a ComponentTreeNode.
     *
     * @param componentRegistry
     */
    public ComponentTreeNode(ComponentRegistry componentRegistry) {
        super(componentRegistry);
        this.componentRegistry = componentRegistry;
    }

    /**
     * @return The component reference.
     */
    public ComponentReference getComponentReference() {
        return this.componentReference;
    }

    /**
     * @param componentRegistry
     */
    public void setComponentRegistry(ComponentRegistry componentRegistry) {
        super.setUserObject(componentRegistry);
        this.componentRegistry = componentRegistry;
    }

    /**
     * @return The component registry.
     */
    public ComponentRegistry getComponentRegistry() {
        return this.componentRegistry;
    }

    /**
     * @see javax.swing.tree.DefaultMutableTreeNode#insert(javax.swing.tree.MutableTreeNode,
     *      int)
     */
    @Override
    public void insert(MutableTreeNode newChild, int childIndex) {
        if (!(newChild instanceof ComponentTreeNode)) {
            throw new IllegalArgumentException();
        }
        super.insert(newChild, childIndex);
    }

    /**
     * @return The children.
     */
    @SuppressWarnings("unchecked")
    public List<ComponentTreeNode> getChildren() {
        return this.children;
    }
}

/*
 * Indiana University Extreme! Lab Software License, Version 1.2
 * 
 * Copyright (c) 2006 The Trustees of Indiana University. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1) All redistributions of source code must retain the above copyright notice,
 * the list of authors in the original source code, this list of conditions and
 * the disclaimer listed in this license;
 * 
 * 2) All redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the disclaimer listed in this license in
 * the documentation and/or other materials provided with the distribution;
 * 
 * 3) Any documentation included with all redistributions must include the
 * following acknowledgement:
 * 
 * "This product includes software developed by the Indiana University Extreme!
 * Lab. For further information please visit http://www.extreme.indiana.edu/"
 * 
 * Alternatively, this acknowledgment may appear in the software itself, and
 * wherever such third-party acknowledgments normally appear.
 * 
 * 4) The name "Indiana University" or "Indiana University Extreme! Lab" shall
 * not be used to endorse or promote products derived from this software without
 * prior written permission from Indiana University. For written permission,
 * please contact http://www.extreme.indiana.edu/.
 * 
 * 5) Products derived from this software may not use "Indiana University" name
 * nor may "Indiana University" appear in their name, without prior written
 * permission of the Indiana University.
 * 
 * Indiana University provides no reassurances that the source code provided
 * does not infringe the patent or any other intellectual property rights of any
 * other entity. Indiana University disclaims any liability to any recipient for
 * claims brought by any other entity based on infringement of intellectual
 * property rights or otherwise.
 * 
 * LICENSEE UNDERSTANDS THAT SOFTWARE IS PROVIDED "AS IS" FOR WHICH NO
 * WARRANTIES AS TO CAPABILITIES OR ACCURACY ARE MADE. INDIANA UNIVERSITY GIVES
 * NO WARRANTIES AND MAKES NO REPRESENTATION THAT SOFTWARE IS FREE OF
 * INFRINGEMENT OF THIRD PARTY PATENT, COPYRIGHT, OR OTHER PROPRIETARY RIGHTS.
 * INDIANA UNIVERSITY MAKES NO WARRANTIES THAT SOFTWARE IS FREE FROM "BUGS",
 * "VIRUSES", "TROJAN HORSES", "TRAP DOORS", "WORMS", OR OTHER HARMFUL CODE.
 * LICENSEE ASSUMES THE ENTIRE RISK AS TO THE PERFORMANCE OF SOFTWARE AND/OR
 * ASSOCIATED MATERIALS, AND TO THE PERFORMANCE AND VALIDITY OF INFORMATION
 * GENERATED USING SOFTWARE.
 */
